#
# spec file for package cereal
#
# Copyright (c) 2022 SUSE LLC
# Copyright (c) 2016 Christoph Junghans
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           cereal
Version:        1.3.2
Release:        1.8
Summary:        A header-only C++11 serialization library
License:        BSD-3-Clause
Group:          Development/Libraries/C and C++
URL:            https://uscilab.github.io/cereal/
Source0:        https://github.com/USCiLab/cereal/archive/v%{version}/%{name}-%{version}.tar.gz
BuildRequires:  cmake
BuildRequires:  gcc-c++
BuildRequires:  libboost_serialization-devel
BuildRequires:  libboost_test-devel

%description
cereal is a header-only C++11 serialization library. cereal takes arbitrary
data types and reversibly turns them into different representations, such as
compact binary encodings, XML, or JSON. cereal was designed to be fast,
light-weight, and easy to extend - it has no external dependencies and can be
easily bundled with other code or used standalone.

%package devel
Summary:        Development headers and libraries for cereal library
Group:          Development/Libraries/C and C++

%description devel
cereal is a header-only C++11 serialization library. cereal takes arbitrary
data types and reversibly turns them into different representations, such as
compact binary encodings, XML, or JSON. cereal was designed to be fast,
light-weight, and easy to extend - it has no external dependencies and can be
easily bundled with other code or used standalone.

This package contains development headers and libraries for the cereal library

%prep
%autosetup -p1

%build
%cmake -DSKIP_PORTABILITY_TEST=ON -DWITH_WERROR=OFF
%cmake_build

%install
%cmake_install

%check
%ctest

%files devel
%license LICENSE
%doc README.md
%{_includedir}/cereal
%{_libdir}/cmake/cereal

%changelog
* Sat Jul  9 2022 Antoine Belvire <antoine.belvire@opensuse.org>
- Update to version 1.3.2:
  * Make doxygen docs reproducible by @mr-c in #740
  * Add CMake options for building doc and sandbox by @AzothAmmo in #751
  * Correct patch version for 1.3.2 by @AzothAmmo in #750
- Changes from version 1.3.1:
  * Github actions in place of Travis CI (thanks to @isuruf, #727)
  * Doctest updates (and upstream patches!) to support all targeted compilers (#714, #736)
  * Cmake modernization (thanks to @ClausKlein, #659)
  * Fix typo in docs by @tankorsmash in #597
  * Add MSVC 2019 to build, default ctor for static object by @AzothAmmo in #593
  * Fix json.hpp compilation issue when int32_t is a long by @bblackham in #621
  * [cpp20] explicitly capture 'this' as copy by @lukaszgemborowski in #640
  * Fix rapidjson for Clang 10 by @groscoe2 in #645
  * Fixes to prevent clang-diagnostic errors by @johngladp in #643
  * cleanup cmake files to be a little more moderen by @ClausKlein in #659
  * CVE-2020-11105: Store a copy of each serialized shared_ptr within the archive to prevent the shared_ptr to be freed to early. by @serpedon in #667
  * add license files for components of cereal by @miartad in #676
  * Catch short documents in JSON input by @johnkeeping in #677
  * C++17: use inline globals for StaticObjects by @InBetweenNames in #657
  * Use std::variant::emplace when loading by @kepler-5 in #699
  * Use std::optional::emplace() when loading non-empty optional by @kepler-5 in #698
  * Fix itsNextName not clearing when not found + style change by @AzothAmmo in #715
  * Update doctest to 2.4.6 + local fixes slated for upstream by @AzothAmmo in #716
  * Fixed loading of std::vector by @Darred in #732
  * Update license to match BSD template by @AzothAmmo in #735
  * Update doctest to 2.4.7 by @AzothAmmo in #736
  * Use GNUInstallDirs instead of hard wiring install directories by @antonblanchard in #710
- Remove d7b68df.patch: Fixed upstream.
- Refresh spec file:
  * Use more cmake macros.
  * Drop obsolete conditionals.
* Mon Oct  4 2021 Christophe Giboudeaux <christophe@krop.fr>
- Add patch to fix build with glibc 2.34:
  * d7b68df.patch
* Sat Aug 15 2020 Dirk Mueller <dmueller@suse.com>
- update to 1.3.0:
  * Deferred serialization for smart pointers (#185)
  * Initial support for C++17 standard library variant and optional (thanks to @arximboldi, #448)
  * Support for std::atomic (thanks to @bluescarni, #277)
  * Vastly improved continuous integration testing (#568, #569)
  * Fixed several issues related to compilation on newer compilers (#579, #587, #515)
  * Fixed warnings with -Wconversion and -Wdocumentation (thanks to @WSoptics, #423)
  * Performance improvements for polymorphic serialization (#354)
  * Fixed a bug related to CEREAL_REGISTER_DYNAMIC_INIT with shared libraries (thanks to @M2tM, #523)
  * Avoid unnecessary undefined behavior with StaticObject (thanks to @erichkeane, #470)
  * New version.hpp file describes cereal version (#444)
  * Ability to disable size=dynamic attribute in the XML archive (thanks to @hoensr, #401)
  remove 8b8f5814e292e03bb5b07333a0e634ef0481c85b.patch: upstream
* Thu Feb 16 2017 junghans@votca.org
- added 8b8f5814e292e03bb5b07333a0e634ef0481c85b.patch from upsteam
  to fix unstable test
* Wed Feb 15 2017 junghans@votca.org
- update to version 1.2.2
* Wed Feb  1 2017 adam.majer@suse.de
- use individual libboost-*-devel packages instead of boost-devel
* Fri Sep  2 2016 junghans@votca.org
- disable PORTABILITY_TEST to support arm
* Wed Aug 31 2016 junghans@votca.org
- Initial version 1.2.1
